<?php

namespace IQBall\App\Controller;

use IQBall\App\Session\SessionHandle;
use IQBall\App\ViewHttpResponse;
use IQBall\Core\Model\TacticModel;
use IQBall\Core\Model\TeamModel;

class TacticController
{
    private TacticModel $tactics;
    private ?TeamModel $teams;

    public function __construct(TacticModel $tactics, ?TeamModel $teams = NULL) {
        $this->tactics = $tactics;
        $this->teams = $teams;
    }

    public function displayTactic(SessionHandle $session): ViewHttpResponse {
        $results = $this->tactics->getAll($session->getAccount()->getId());
        return ViewHttpResponse::twig("display_tactic.html.twig", ['tactics' => $results]);
    }

    public function displayTeam(int $tacticId, SessionHandle $session): ViewHttpResponse {
        $results = $this->teams->getAll($session->getAccount()->getId());
        return ViewHttpResponse::twig("display_user_teams.html.twig", ['teams' => $results, 'tactic' => $tacticId]);
    }

    public function displayShareConfirmation(int $tacticId, int $teamId, SessionHandle $session) : ViewHttpResponse {
        $team = $this->teams->getTeam($teamId);
        $tactic = $this->tactics->get($tacticId);
        return ViewHttpResponse::twig("display_share_confirmation.html.twig", ['team' => $teamId, 'tactic' => $tacticId]);
    }

    public function shareTacticToTeam(array $confirmation, int $tacticId, int $teamId, SessionHandle $session) : \IQBall\Core\Http\HttpResponse
    {
        if($confirmation['confirmation'] == "no") {
            return ViewHttpResponse::redirect("/");
        }
        $this->teams->shareTacticToTeam($teamId, $tacticId);
        return ViewHttpResponse::redirect("/");
    }
}
